Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( ColorError = color.New(color.FgRed) ColorWarning = color.New(color.FgYellow) ColorSuccess = color.New(color.FgGreen) ColorHeader = color.New(color.FgGreen) ColorSeparator = color.New(color.FgMagenta) ColorDim = color.New(color.Faint) ColorCyan = color.New(color.FgCyan) ColorBlue = color.New(color.FgBlue) ColorHiYellow = color.New(color.FgHiYellow) // Module category colours ColorAgents = color.New(color.FgBlue) ColorRoles = color.New(color.FgGreen) ColorContexts = color.New(color.FgCyan) ColorTasks = color.New(color.FgHiYellow) ColorSettings = color.New(color.FgMagenta) ColorPrompts = color.New(color.Faint) ColorPaths = color.New(color.FgHiCyan) ColorInstalled = color.New(color.FgHiGreen) ColorRegistry = color.New(color.FgYellow) )
Functions ¶
func CategoryColor ¶
CategoryColor returns the colour for a module category. Matching is case-insensitive.
Types ¶
type Progress ¶
type Progress struct {
// contains filtered or unexported fields
}
Progress provides an in-place progress indicator using carriage return. Each Update overwrites the previous line. Done clears it. When the writer is not a terminal, Update and Done are no-ops.
func NewProgress ¶
NewProgress creates a progress writer. Carriage-return progress output is suppressed when w is not a terminal or quiet is true.
Click to show internal directories.
Click to hide internal directories.